==> deepin-home_1.6.0.tar.xz: BUILD/translations/deepin-home/it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Loggati col Deepin ID</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Devi loggarti per poter eseguire qualsiasi operazione</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Stai avanzando troppe richieste, riprova più tardi</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Devi loggarti per poter eseguire qualsiasi operazione</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Errore di rete, riprova più tardi</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation>I miei preferiti</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>Unlogged</source>
        <translation>Non loggato</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Accedi</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>I miei feedback</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizzazione</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Rimuovi dai preferiti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Annulla il sollecito</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Sollecita l&apos;aggiornamento</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>In arrivo</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Risposta ufficiale</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Newest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicazione</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuti e condividi qui</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Report delle anomalie</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Segnala le anomalie riscontrate</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Conferma il tuo suggerimento</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Risorse</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Questionario</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Unisciti a Noi</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Internal Testing</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>News della Community</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation>Messaggi</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Questionari</translation>
    </message>
    <message>
        <source>No more items</source>
        <translation>Nessun ulteriore elemento</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Avvia all&apos;accensione del PC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Accedi rapidamente ai forum, invia suggerimenti e segnala anomalie.
Localizzazione italiana a cura di Carofano Massimo Antonio.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Nessun messaggio al momento</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 messaggi</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Segna come già letti</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Sfoglia ulteriormente</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Errore di rete, riprova più tardi</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Nessun questionario al momento.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Scade in: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Compila</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>In attesa</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermata</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Risposta</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Risolta</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>In valutazione</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Accettata</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completata</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Riproduzione</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Il problema non è stato analizzato e non verrà visualizzato nell&apos;elenco pubblico.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Attualmente non è possibile identificare la causa; sono necessari ulteriori indagini ed un adeguato monitoraggio.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>La problematica è stata riprodotta e la causa è stata correttamente identificata.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>La problematica non è un bug oppure è di natura differente.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>La problematica è stata risolta ed in attesa della prossima release applicativa ufficiale.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Il requisito non è stato analizzato e non verrà visualizzato nell&apos;elenco pubblico.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Il problema è stato riconosciuto ed è in fase di valutazione interna.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Incluso nei futuri rilasci applicativi.</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Il requisito non è accettato o non può essere correttamente indirizzato.</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Sviluppo terminato, in attesa della release applicativa.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Impossibile aggiungere uno screenshot.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>L&apos;immagine non può essere inferiore a 1MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Il formato immagine non è supportato.</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Conferma feedback</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Stato attuale del prodotto]:
[Prodotto desiderato]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Precondizioni]:
[Come riprodurlo]:
[Risultati attesi]:
[Risultati attuali]:</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tipologia:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Anomalia</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Fornisci una breve descrizione dell&apos;anomalia</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contenuto:</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Non iserire più requisiti in un unico feedback</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versione di Sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Info dispositivo:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;info dispositivo&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Screenshot:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>File immagine</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Trascina qui i file oppure clicca il bottone per caricare fino a tre immagini</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Sicuro di voler uscire?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Il contenuto del feedback non è stato salvato.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Impossibile confermare il feedback.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Inserisci un titolo ed un contenuto chiaro e comprensibile.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Inserisci il titolo del tuo feedback.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Inserisci il contenuto del tuo feedback.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Indirizzo email non corretto.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Info dispositivo</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Inserisci il tuo indirizzo email</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Non iserire più requisiti in un unico feedback</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Hub Feedback</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>I miei feedback</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>I miei preferiti</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>I miei solleciti</translation>
    </message>
</context>
</TS>

==> deepin-home_1.6.4.tar.xz: BUILD/translations/deepin-home/it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Loggati col Deepin ID</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Devi loggarti per poter eseguire qualsiasi operazione</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Stai avanzando troppe richieste, riprova più tardi</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Devi loggarti per poter eseguire qualsiasi operazione</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Errore di rete, riprova più tardi</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Non loggato</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>I miei preferiti</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>I miei feedback</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Disconnessione</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Accedi</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visualizzazione</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Rimuovi dai preferiti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferito</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Annulla il sollecito</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Sollecita l&apos;aggiornamento</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>In arrivo</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Risposta ufficiale</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Bug</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versione:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Ordinamento:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Più recenti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Urgenti</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Comunicazione</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuti e condividi qui</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Report delle anomalie</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Segnala le anomalie riscontrate</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Conferma il tuo suggerimento</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Risorse</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Questionario</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Unisciti a Noi</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Internal Testing</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Community News</source>
        <translation>News della Community</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Nessun ulteriore elemento</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Messaggi</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Questionari</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Avvia all&apos;accensione del PC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Accedi rapidamente ai forum, invia suggerimenti e segnala anomalie.
Localizzazione italiana a cura di Carofano Massimo Antonio.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Nessun messaggio al momento</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 messaggi</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Segna come già letti</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Sfoglia ulteriormente</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Errore di rete, riprova più tardi</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Nessun questionario al momento.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Scade in: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Compila</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>In attesa</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Riproduzione</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confermata</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Risposta</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Risolta</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>In valutazione</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Accettata</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completata</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Il problema non è stato analizzato e non verrà visualizzato nell&apos;elenco pubblico.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Attualmente non è possibile identificare la causa; sono necessari ulteriori indagini ed un adeguato monitoraggio.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>La problematica è stata riprodotta e la causa è stata correttamente identificata.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>La problematica non è un bug oppure è di natura differente.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>La problematica è stata risolta ed in attesa della prossima release applicativa ufficiale.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Il requisito non è stato analizzato e non verrà visualizzato nell&apos;elenco pubblico.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Il problema è stato riconosciuto ed è in fase di valutazione interna.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Incluso nei futuri rilasci applicativi.</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Il requisito non è accettato o non può essere correttamente indirizzato.</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Sviluppo terminato, in attesa della release applicativa.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Impossibile aggiungere uno screenshot.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>L&apos;immagine non può essere inferiore a 1MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Il formato immagine non è supportato.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Stato attuale del prodotto]:
[Prodotto desiderato]:</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Precondizioni]:
[Come riprodurlo]:
[Risultati attesi]:
[Risultati attuali]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Conferma feedback</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Tipologia:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggerimenti</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Anomalia</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titolo:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Fornisci una breve descrizione dell&apos;anomalia</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Contenuto:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Non iserire più requisiti in un unico feedback</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Non iserire più requisiti in un unico feedback</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>Email:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Inserisci il tuo indirizzo email</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Versione di Sistema:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Info dispositivo:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;info dispositivo&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Screenshot:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>File immagine</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Trascina qui i file oppure clicca il bottone per caricare fino a tre immagini</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Sicuro di voler uscire?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Il contenuto del feedback non è stato salvato.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Impossibile confermare il feedback.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Inserisci un titolo ed un contenuto chiaro e comprensibile.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Inserisci il titolo del tuo feedback.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Inserisci il contenuto del tuo feedback.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Indirizzo email non corretto.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Info dispositivo</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Hub Feedback</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>I miei feedback</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>I miei preferiti</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>I miei solleciti</translation>
    </message>
</context>
</TS>
